=============
Gondor client
=============


.. image:: https://img.shields.io/travis/eldarion/gondor.svg
    :target: https://travis-ci.org/eldarion/gondor

.. image:: https://img.shields.io/coveralls/eldarion/gondor.svg
    :target: https://coveralls.io/r/eldarion/gondor

.. image:: https://img.shields.io/pypi/dm/gondor.svg
    :target:  https://pypi.python.org/pypi/gondor/

.. image:: https://img.shields.io/pypi/v/gondor.svg
    :target:  https://pypi.python.org/pypi/gondor/

.. image:: https://img.shields.io/badge/license-BSD-blue.svg
    :target:  https://pypi.python.org/pypi/gondor/


For more information see https://gondor.io/support/
